summaryrefslogtreecommitdiff
path: root/vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php')
-rw-r--r--vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php b/vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php
index 5596330881..5bdacf6914 100644
--- a/vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php
+++ b/vendor/symfony/http-kernel/Exception/NotAcceptableHttpException.php
@@ -18,11 +18,11 @@ class NotAcceptableHttpException extends HttpException
{
/**
* @param string $message The internal exception message
* @param \Exception $previous The previous exception
* @param int $code The internal exception code
* @param array $headers
*/
- public function __construct(string $message = null, \Exception $previous = null, int $code = 0, array $headers = [])
+ public function __construct(string $message = null, \Throwable $previous = null, int $code = 0, array $headers = [])
{
parent::__construct(406, $message, $previous, $headers, $code);
}
@@ -18,11 +18,11 @@ class NotAcceptableHttpException extends HttpException
/**
* @param string $message The internal exception message
- * @param \Exception $previous The previous exception
+ * @param \Throwable $previous The previous exception
* @param int $code The internal exception code
* @param array $headers